Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3446)

Unified Diff: base/test/launcher/test_result.h

Issue 2406243004: Introduce test output snippet byte limit (Closed)
Patch Set: 2.5 MB Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/test/launcher/test_launcher.cc ('k') | base/test/launcher/test_result.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/test/launcher/test_result.h
diff --git a/base/test/launcher/test_result.h b/base/test/launcher/test_result.h
index b61cdd4b932ca42bfa35dbf539e21849eb54d118..19c6ba5cfc9edb8a96ad4c7d0e8e00cc1623e352 100644
--- a/base/test/launcher/test_result.h
+++ b/base/test/launcher/test_result.h
@@ -14,13 +14,14 @@ namespace base {
// Structure containing result of a single test.
struct TestResult {
enum Status {
- TEST_UNKNOWN, // Status not set.
- TEST_SUCCESS, // Test passed.
- TEST_FAILURE, // Assertion failure (think EXPECT_TRUE, not DCHECK).
- TEST_FAILURE_ON_EXIT, // Test passed but executable exit code was non-zero.
- TEST_TIMEOUT, // Test timed out and was killed.
- TEST_CRASH, // Test crashed (includes CHECK/DCHECK failures).
- TEST_SKIPPED, // Test skipped (not run at all).
+ TEST_UNKNOWN, // Status not set.
+ TEST_SUCCESS, // Test passed.
+ TEST_FAILURE, // Assertion failure (e.g. EXPECT_TRUE, not DCHECK).
+ TEST_FAILURE_ON_EXIT, // Passed but executable exit code was non-zero.
+ TEST_TIMEOUT, // Test timed out and was killed.
+ TEST_CRASH, // Test crashed (includes CHECK/DCHECK failures).
+ TEST_SKIPPED, // Test skipped (not run at all).
+ TEST_EXCESSIVE_OUTPUT, // Test exceeded output limit.
};
TestResult();
@@ -41,7 +42,8 @@ struct TestResult {
bool completed() const {
return status == TEST_SUCCESS ||
status == TEST_FAILURE ||
- status == TEST_FAILURE_ON_EXIT;
+ status == TEST_FAILURE_ON_EXIT ||
+ status == TEST_EXCESSIVE_OUTPUT;
}
// Full name of the test (e.g. "A.B").
« no previous file with comments | « base/test/launcher/test_launcher.cc ('k') | base/test/launcher/test_result.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698